@@ -34,7 +34,7 @@ class ApiClient(object):
     }
 
     def __init__(self, host=None, access_key=None):
-        self.host = host
+        self.host = host if host.startswith('http') else f"https://{host}"
         self.access_key = access_key
         self.token = None
         self.pool = ThreadPool()
@@ -56,8 +56,8 @@ class ApiClient(object):
 
     def get_user_from_token(self):
         token = self.default_headers['Authorization'].replace("Bearer", "").strip()
-        jwtData = jwt.decode(token, verify=False)
-        if 'https://api.authress.io' in jwtData['aud']:
+        jwtData = jwt.decode(token, options={"verify_signature": False})
+        if 'aud' in jwtData and 'https://api.authress.io' in jwtData['aud']:
           return f"Authress|{jwtData['sub']}"
 
         return jwtData['sub']
@@ -554,7 +554,7 @@ class ApiClient(object):
 
       current_token_is_valid = False
       try:
-        current_token_is_valid = self.token is not None and jwt.decode(self.token, verify=False, options={"verify_signature": False}, algorithms=['RS256', 'EdDSA'])['exp'] > (datetime.datetime.utcnow() + datetime.timedelta(seconds=3600)).timestamp()
+        current_token_is_valid = self.token is not None and jwt.decode(self.token, options={"verify_signature": False})['exp'] > (datetime.datetime.utcnow() + datetime.timedelta(seconds=3600)).timestamp()
       except jwt.ExpiredSignatureError:
         current_token_is_valid = False
 
@@ -573,9 +573,11 @@ class ApiClient(object):
         }
         algorithm = 'EdDSA'
 
+      issuer_origin = "https://api.authress.io" if (self.host == None or self.host == '' or '.authress.io' in self.host) else self.host
       payload = {
-        'iss': f"https://api.authress.io/v1/clients/{quote(decoded_access_key['clientId'], safe='')}",
+        'iss': f"{issuer_origin}/v1/clients/{quote(decoded_access_key['clientId'], safe='')}",
         'aud': decoded_access_key['audience'],
+        'iat': datetime.datetime.utcnow(),
         'exp': datetime.datetime.utcnow() + datetime.timedelta(seconds=86400),
         'sub': decoded_access_key['clientId'],
         'scopes': 'openId'
@@ -583,4 +585,4 @@ class ApiClient(object):
 
       jwt_token = jwt.encode(payload, decoded_access_key['privateKey'], algorithm=algorithm, headers={'kid': decoded_access_key['keyId'] })
       self.token = jwt_token if isinstance(jwt_token, str) else jwt_token.decode("utf-8")
-      return self.token
\ No newline at end of file
+      return self.token
